mod sensors;
mod comm;

use comm::Channel;
use std::io;
use std::sync::mpsc;
use std::thread;


fn main() {
    let (tx, rx) = mpsc::channel::<String>();
    make_thread(&tx, stdin);
    make_thread(&tx, sensors::sensors);
    loop {
        println!("%{{r}}{}", rx.recv().ok().unwrap());
    }
}

fn make_thread(tx: &Channel, func: fn(&Channel) -> ()) {
    let thread_tx = tx.clone();
    thread::spawn(move || {
        func(&thread_tx);
    });
}

fn stdin(tx: &Channel) {
    let mut line = String::new();
    loop {
        io::stdin().read_line(&mut line).ok().expect("Failed to read line");
        tx.send(line.clone()).ok().expect("Couldn't send data");
    }
}

